@@ -1,20 +1,8 @@
 /*
- * Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
- * Copyright (c) 2010 Tobias Koenig <tokoe@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kdab.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "aclentrydialog_p.h"
@@ -80,7 +68,7 @@ AclEntryDialog::AclEntryDialog(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setDefault(true);
@@ -92,7 +80,7 @@ AclEntryDialog::AclEntryDialog(QWidget *parent)
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    QGridLayout *layout = new QGridLayout(page);
+    auto *layout = new QGridLayout(page);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QLabel *label = new QLabel(i18n("&User identifier:"), page);
