@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -27,7 +14,7 @@
 #include <KEmailAddress>
 
 #include "imapaclattribute.h"
-#include "job/fetchrecursivecollectionsjob.h"
+
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <QDBusInterface>
@@ -35,7 +22,10 @@
 #include <ContactGroupSearchJob>
 #include <ContactGroupExpandJob>
 #include <AkonadiCore/CollectionModifyJob>
+#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/CollectionFetchScope>
 #include <KContacts/Addressee>
+#include <collectionfetchjob.h>
 
 using namespace PimCommon;
 //#define SEARCHCONTACT_AKONADI 1
@@ -55,7 +45,7 @@ void AclModifyJob::searchContact()
 {
     const QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator itEnd = mCurrentRight.cend();
     if (mIt != itEnd) {
-        Akonadi::ContactGroupSearchJob *searchJob = new Akonadi::ContactGroupSearchJob(this);
+        auto *searchJob = new Akonadi::ContactGroupSearchJob(this);
         searchJob->setQuery(Akonadi::ContactGroupSearchJob::Name, QString::fromLatin1(mIt.key()));
         searchJob->setLimit(1);
         connect(searchJob, &Akonadi::ContactGroupSearchJob::result, this, &AclModifyJob::slotGroupSearchResult);
@@ -66,7 +56,7 @@ void AclModifyJob::searchContact()
 
 void AclModifyJob::slotGroupSearchResult(KJob *job)
 {
-    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    auto *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
     if (!searchJob->contactGroups().isEmpty()) {   // it has been a distribution list
         Akonadi::ContactGroupExpandJob *expandJob
             = new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
@@ -117,11 +107,18 @@ void AclModifyJob::slotModifyAcl()
 {
     mCurrentIndex = 0;
     if (mRecursive) {
-        PimCommon::FetchRecursiveCollectionsJob *fetchJob = new PimCommon::FetchRecursiveCollectionsJob(this);
-        fetchJob->setTopCollection(mTopLevelCollection);
-        connect(fetchJob, &FetchRecursiveCollectionsJob::fetchCollectionFailed, this, &AclModifyJob::slotFetchCollectionFailed);
-        connect(fetchJob, &FetchRecursiveCollectionsJob::fetchCollectionFinished, this, &AclModifyJob::slotFetchCollectionFinished);
-        fetchJob->start();
+        auto job = new Akonadi::CollectionFetchJob(mTopLevelCollection, Akonadi::CollectionFetchJob::Recursive, this);
+        job->fetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
+        connect(job, &Akonadi::CollectionFetchJob::finished,
+                this, [this](KJob *job) {
+            if (job->error()) {
+                qCWarning(PIMCOMMONAKONADI_LOG) << job->errorString();
+                slotFetchCollectionFailed();
+            } else {
+                auto fetch = static_cast<Akonadi::CollectionFetchJob *>(job);
+                slotFetchCollectionFinished(fetch->collections());
+            }
+        });
     } else {
         changeAcl(mTopLevelCollection);
     }
@@ -185,10 +182,10 @@ void AclModifyJob::changeAcl(const Akonadi::Collection &collection)
 {
     if (collection.hasAttribute<PimCommon::ImapAclAttribute>()) {
         Akonadi::Collection mutableCollection = collection;
-        PimCommon::ImapAclAttribute *attribute = mutableCollection.attribute<PimCommon::ImapAclAttribute>();
+        auto *attribute = mutableCollection.attribute<PimCommon::ImapAclAttribute>();
         if (canAdministrate(attribute, mutableCollection)) {
             attribute->setRights(mNewRight);
-            Akonadi::CollectionModifyJob *modifyJob = new Akonadi::CollectionModifyJob(mutableCollection);
+            auto *modifyJob = new Akonadi::CollectionModifyJob(mutableCollection);
             connect(modifyJob, &KJob::result, this, &AclModifyJob::slotModifyDone);
         }
     } else {
@@ -219,7 +216,7 @@ void AclModifyJob::slotFetchCollectionFinished(const Akonadi::Collection::List &
     QStringList folderNames;
     for (const Akonadi::Collection &col : collectionList) {
         if (col.hasAttribute<PimCommon::ImapAclAttribute>()) {
-            const PimCommon::ImapAclAttribute *attribute = col.attribute<PimCommon::ImapAclAttribute>();
+            const auto *attribute = col.attribute<PimCommon::ImapAclAttribute>();
             if (canAdministrate(attribute, col)) {
                 QString fullName;
                 bool parentFound;
