@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imapresourcecapabilitiesmanager.h"
@@ -23,7 +11,7 @@
 #include <AkonadiCore/AgentManager>
 #include <AkonadiCore/ServerManager>
 
-#include <KDBusConnectionPool>
+#include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusPendingCall>
 #include <QDBusPendingReply>
@@ -57,11 +45,11 @@ void ImapResourceCapabilitiesManager::searchCapabilities(const QString &identifi
         = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
     QDBusInterface iface(service,
                          QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-                         KDBusConnectionPool::threadConnection(), this);
+                         QDBusConnection::sessionBus(), this);
 
     if (iface.isValid()) {
         QDBusPendingCall call = iface.asyncCall(QStringLiteral("serverCapabilities"));
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+        auto *watcher = new QDBusPendingCallWatcher(call, this);
         watcher->setProperty("identifier", identifier);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &ImapResourceCapabilitiesManager::slotCapabilities);
     } else {
